import type { CustomizableBytes, LayoutToType } from "@wormhole-foundation/sdk-base";
import { RegisterPayloadTypes } from "@wormhole-foundation/sdk-definitions";
export declare const trimmedAmountLayout: readonly [{
    readonly name: "decimals";
    readonly binary: "uint";
    readonly size: 1;
}, {
    readonly name: "amount";
    readonly binary: "uint";
    readonly size: 8;
}];
export type TrimmedAmount = LayoutToType<typeof trimmedAmountLayout>;
export type Prefix = readonly [number, number, number, number];
export declare const nativeTokenTransferLayout: readonly [{
    readonly name: "prefix";
    readonly binary: "bytes";
    readonly custom: Uint8Array;
    readonly omit: true;
}, {
    readonly name: "trimmedAmount";
    readonly binary: "bytes";
    readonly layout: readonly [{
        readonly name: "decimals";
        readonly binary: "uint";
        readonly size: 1;
    }, {
        readonly name: "amount";
        readonly binary: "uint";
        readonly size: 8;
    }];
}, {
    readonly binary: "bytes";
    readonly size: 32;
    readonly custom: {
        to: (val: Uint8Array) => import("@wormhole-foundation/sdk-definitions").UniversalAddress;
        from: (val: import("@wormhole-foundation/sdk-definitions").UniversalAddress) => Uint8Array;
    };
    readonly name: "sourceToken";
}, {
    readonly binary: "bytes";
    readonly size: 32;
    readonly custom: {
        to: (val: Uint8Array) => import("@wormhole-foundation/sdk-definitions").UniversalAddress;
        from: (val: import("@wormhole-foundation/sdk-definitions").UniversalAddress) => Uint8Array;
    };
    readonly name: "recipientAddress";
}, {
    readonly custom: {
        to: (val: number) => "Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Scroll" | "Mantle" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Neutron" | "Celestia" | "Stargaze" | "Seda" | "Dymension" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" | "PolygonSepolia";
        from: (val: "Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Scroll" | "Mantle" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Neutron" | "Celestia" | "Stargaze" | "Seda" | "Dymension" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" | "PolygonSepolia") => number;
    };
    readonly binary: "uint";
    readonly size: 2;
    readonly name: "recipientChain";
}];
export type NativeTokenTransfer = LayoutToType<typeof nativeTokenTransferLayout>;
export declare const transceiverMessageLayout: <const MP extends CustomizableBytes = undefined, const TP extends CustomizableBytes = undefined>(prefix: Prefix, nttManagerPayload?: MP, transceiverPayload?: TP) => readonly [{
    readonly name: "prefix";
    readonly binary: "bytes";
    readonly custom: Uint8Array;
    readonly omit: true;
}, {
    readonly binary: "bytes";
    readonly size: 32;
    readonly custom: {
        to: (val: Uint8Array) => import("@wormhole-foundation/sdk-definitions").UniversalAddress;
        from: (val: import("@wormhole-foundation/sdk-definitions").UniversalAddress) => Uint8Array;
    };
    readonly name: "sourceNttManager";
}, {
    readonly binary: "bytes";
    readonly size: 32;
    readonly custom: {
        to: (val: Uint8Array) => import("@wormhole-foundation/sdk-definitions").UniversalAddress;
        from: (val: import("@wormhole-foundation/sdk-definitions").UniversalAddress) => Uint8Array;
    };
    readonly name: "recipientNttManager";
}, import("@wormhole-foundation/sdk-base").CustomizableBytesReturn<{
    readonly name: "nttManagerPayload";
    readonly lengthSize: 2;
}, MP>, import("@wormhole-foundation/sdk-base").CustomizableBytesReturn<{
    readonly name: "transceiverPayload";
    readonly lengthSize: 2;
}, TP>];
export type TransceiverMessage<MP extends CustomizableBytes = undefined, TP extends CustomizableBytes = undefined> = LayoutToType<ReturnType<typeof transceiverMessageLayout<MP, TP>>>;
export declare const nttManagerMessageLayout: <const P extends CustomizableBytes = undefined>(customPayload?: P) => readonly [{
    readonly name: "id";
    readonly binary: "bytes";
    readonly size: 32;
}, {
    readonly binary: "bytes";
    readonly size: 32;
    readonly custom: {
        to: (val: Uint8Array) => import("@wormhole-foundation/sdk-definitions").UniversalAddress;
        from: (val: import("@wormhole-foundation/sdk-definitions").UniversalAddress) => Uint8Array;
    };
    readonly name: "sender";
}, import("@wormhole-foundation/sdk-base").CustomizableBytesReturn<{
    readonly name: "payload";
    readonly lengthSize: 2;
}, P>];
export type NttManagerMessage<P extends CustomizableBytes = undefined> = LayoutToType<ReturnType<typeof nttManagerMessageLayout<P>>>;
declare const optionalWormholeTransceiverPayloadLayout: readonly [{
    readonly name: "version";
    readonly binary: "uint";
    readonly size: 2;
    readonly custom: 1;
    readonly omit: true;
}, {
    readonly name: "forSpecializedRelayer";
    readonly binary: "uint";
    readonly size: 1;
    readonly custom: {
        readonly to: (val: number) => boolean;
        readonly from: (val: boolean) => 1 | 0;
    };
}];
type OptionalWormholeTransceiverPayload = LayoutToType<typeof optionalWormholeTransceiverPayloadLayout>;
export declare const wormholeTransceiverMessageLayout: <MP extends CustomizableBytes = undefined>(nttManagerPayload?: MP) => readonly [{
    readonly name: "prefix";
    readonly binary: "bytes";
    readonly custom: Uint8Array;
    readonly omit: true;
}, {
    readonly binary: "bytes";
    readonly size: 32;
    readonly custom: {
        to: (val: Uint8Array) => import("@wormhole-foundation/sdk-definitions").UniversalAddress;
        from: (val: import("@wormhole-foundation/sdk-definitions").UniversalAddress) => Uint8Array;
    };
    readonly name: "sourceNttManager";
}, {
    readonly binary: "bytes";
    readonly size: 32;
    readonly custom: {
        to: (val: Uint8Array) => import("@wormhole-foundation/sdk-definitions").UniversalAddress;
        from: (val: import("@wormhole-foundation/sdk-definitions").UniversalAddress) => Uint8Array;
    };
    readonly name: "recipientNttManager";
}, import("@wormhole-foundation/sdk-base").CustomizableBytesReturn<{
    readonly name: "nttManagerPayload";
    readonly lengthSize: 2;
}, MP>, import("@wormhole-foundation/sdk-base").CustomizableBytesReturn<{
    readonly name: "transceiverPayload";
    readonly lengthSize: 2;
}, {
    readonly to: (encoded: Uint8Array) => {
        readonly forSpecializedRelayer: boolean;
    } | null;
    readonly from: (value: OptionalWormholeTransceiverPayload | null) => Uint8Array;
}>];
export type WormholeTransceiverMessage<MP extends CustomizableBytes = undefined> = LayoutToType<ReturnType<typeof wormholeTransceiverMessageLayout<MP>>>;
export declare const transceiverInstructionLayout: <const P extends CustomizableBytes = undefined>(customPayload?: P) => readonly [{
    readonly name: "index";
    readonly binary: "uint";
    readonly size: 1;
}, import("@wormhole-foundation/sdk-base").CustomizableBytesReturn<{
    readonly name: "payload";
    readonly lengthSize: 1;
}, P>];
export declare const nttNamedPayloads: readonly [readonly ["WormholeTransfer", readonly [{
    readonly name: "prefix";
    readonly binary: "bytes";
    readonly custom: Uint8Array;
    readonly omit: true;
}, {
    readonly binary: "bytes";
    readonly size: 32;
    readonly custom: {
        to: (val: Uint8Array) => import("@wormhole-foundation/sdk-definitions").UniversalAddress;
        from: (val: import("@wormhole-foundation/sdk-definitions").UniversalAddress) => Uint8Array;
    };
    readonly name: "sourceNttManager";
}, {
    readonly binary: "bytes";
    readonly size: 32;
    readonly custom: {
        to: (val: Uint8Array) => import("@wormhole-foundation/sdk-definitions").UniversalAddress;
        from: (val: import("@wormhole-foundation/sdk-definitions").UniversalAddress) => Uint8Array;
    };
    readonly name: "recipientNttManager";
}, import("@wormhole-foundation/sdk-base").CustomizableBytesReturn<{
    readonly name: "nttManagerPayload";
    readonly lengthSize: 2;
}, readonly [{
    readonly name: "id";
    readonly binary: "bytes";
    readonly size: 32;
}, {
    readonly binary: "bytes";
    readonly size: 32;
    readonly custom: {
        to: (val: Uint8Array) => import("@wormhole-foundation/sdk-definitions").UniversalAddress;
        from: (val: import("@wormhole-foundation/sdk-definitions").UniversalAddress) => Uint8Array;
    };
    readonly name: "sender";
}, import("@wormhole-foundation/sdk-base").CustomizableBytesReturn<{
    readonly name: "payload";
    readonly lengthSize: 2;
}, readonly [{
    readonly name: "prefix";
    readonly binary: "bytes";
    readonly custom: Uint8Array;
    readonly omit: true;
}, {
    readonly name: "trimmedAmount";
    readonly binary: "bytes";
    readonly layout: readonly [{
        readonly name: "decimals";
        readonly binary: "uint";
        readonly size: 1;
    }, {
        readonly name: "amount";
        readonly binary: "uint";
        readonly size: 8;
    }];
}, {
    readonly binary: "bytes";
    readonly size: 32;
    readonly custom: {
        to: (val: Uint8Array) => import("@wormhole-foundation/sdk-definitions").UniversalAddress;
        from: (val: import("@wormhole-foundation/sdk-definitions").UniversalAddress) => Uint8Array;
    };
    readonly name: "sourceToken";
}, {
    readonly binary: "bytes";
    readonly size: 32;
    readonly custom: {
        to: (val: Uint8Array) => import("@wormhole-foundation/sdk-definitions").UniversalAddress;
        from: (val: import("@wormhole-foundation/sdk-definitions").UniversalAddress) => Uint8Array;
    };
    readonly name: "recipientAddress";
}, {
    readonly custom: {
        to: (val: number) => "Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Scroll" | "Mantle" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Neutron" | "Celestia" | "Stargaze" | "Seda" | "Dymension" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" | "PolygonSepolia";
        from: (val: "Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Scroll" | "Mantle" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Neutron" | "Celestia" | "Stargaze" | "Seda" | "Dymension" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" | "PolygonSepolia") => number;
    };
    readonly binary: "uint";
    readonly size: 2;
    readonly name: "recipientChain";
}]>]>, import("@wormhole-foundation/sdk-base").CustomizableBytesReturn<{
    readonly name: "transceiverPayload";
    readonly lengthSize: 2;
}, {
    readonly to: (encoded: Uint8Array) => {
        readonly forSpecializedRelayer: boolean;
    } | null;
    readonly from: (value: OptionalWormholeTransceiverPayload | null) => Uint8Array;
}>]]];
declare module "@wormhole-foundation/sdk-definitions" {
    namespace WormholeRegistry {
        interface PayloadLiteralToLayoutMapping extends RegisterPayloadTypes<"Ntt", typeof nttNamedPayloads> {
        }
    }
}
export {};
//# sourceMappingURL=nttLayout.d.ts.map