"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.nttNamedPayloads = exports.transceiverInstructionLayout = exports.wormholeTransceiverMessageLayout = exports.nttManagerMessageLayout = exports.transceiverMessageLayout = exports.nativeTokenTransferLayout = exports.trimmedAmountLayout = void 0;
const sdk_base_1 = require("@wormhole-foundation/sdk-base");
const sdk_definitions_1 = require("@wormhole-foundation/sdk-definitions");
exports.trimmedAmountLayout = [
    { name: "decimals", binary: "uint", size: 1 },
    { name: "amount", binary: "uint", size: 8 },
];
const prefixItem = (prefix) => ({
    name: "prefix",
    binary: "bytes",
    custom: Uint8Array.from(prefix),
    omit: true,
});
exports.nativeTokenTransferLayout = [
    prefixItem([0x99, 0x4e, 0x54, 0x54]),
    { name: "trimmedAmount", binary: "bytes", layout: exports.trimmedAmountLayout },
    { name: "sourceToken", ...sdk_definitions_1.layoutItems.universalAddressItem },
    { name: "recipientAddress", ...sdk_definitions_1.layoutItems.universalAddressItem },
    { name: "recipientChain", ...sdk_definitions_1.layoutItems.chainItem() }, //TODO restrict to supported chains?
];
const transceiverMessageLayout = (prefix, nttManagerPayload, transceiverPayload) => [
    prefixItem(prefix),
    { name: "sourceNttManager", ...sdk_definitions_1.layoutItems.universalAddressItem },
    { name: "recipientNttManager", ...sdk_definitions_1.layoutItems.universalAddressItem },
    (0, sdk_base_1.customizableBytes)({ name: "nttManagerPayload", lengthSize: 2 }, nttManagerPayload),
    (0, sdk_base_1.customizableBytes)({ name: "transceiverPayload", lengthSize: 2 }, transceiverPayload),
];
exports.transceiverMessageLayout = transceiverMessageLayout;
const nttManagerMessageLayout = (customPayload) => [
    { name: "id", binary: "bytes", size: 32 },
    { name: "sender", ...sdk_definitions_1.layoutItems.universalAddressItem },
    (0, sdk_base_1.customizableBytes)({ name: "payload", lengthSize: 2 }, customPayload),
];
exports.nttManagerMessageLayout = nttManagerMessageLayout;
const optionalWormholeTransceiverPayloadLayout = [
    { name: "version", binary: "uint", size: 2, custom: 1, omit: true },
    {
        name: "forSpecializedRelayer",
        binary: "uint",
        size: 1,
        custom: {
            to: (val) => val > 0,
            from: (val) => (val ? 1 : 0),
        },
    },
];
const optionalWormholeTransceiverPayloadConversion = {
    to: (encoded) => encoded.length === 0
        ? null
        : (0, sdk_base_1.deserializeLayout)(optionalWormholeTransceiverPayloadLayout, encoded),
    from: (value) => value === null
        ? new Uint8Array(0)
        : (0, sdk_base_1.serializeLayout)(optionalWormholeTransceiverPayloadLayout, value),
};
const wormholeTransceiverMessageLayout = (nttManagerPayload) => (0, exports.transceiverMessageLayout)([0x99, 0x45, 0xff, 0x10], nttManagerPayload, optionalWormholeTransceiverPayloadConversion);
exports.wormholeTransceiverMessageLayout = wormholeTransceiverMessageLayout;
const wormholeNativeTokenTransferLayout = (0, exports.wormholeTransceiverMessageLayout)((0, exports.nttManagerMessageLayout)(exports.nativeTokenTransferLayout));
const transceiverInstructionLayout = (customPayload) => [
    { name: "index", binary: "uint", size: 1 },
    (0, sdk_base_1.customizableBytes)({ name: "payload", lengthSize: 1 }, customPayload),
];
exports.transceiverInstructionLayout = transceiverInstructionLayout;
exports.nttNamedPayloads = [
    ["WormholeTransfer", wormholeNativeTokenTransferLayout],
];
(0, sdk_definitions_1.registerPayloadTypes)("Ntt", exports.nttNamedPayloads);
//# sourceMappingURL=nttLayout.js.map