import { customizableBytes, deserializeLayout, serializeLayout, } from "@wormhole-foundation/sdk-base";
import { layoutItems, registerPayloadTypes, } from "@wormhole-foundation/sdk-definitions";
export const trimmedAmountLayout = [
    { name: "decimals", binary: "uint", size: 1 },
    { name: "amount", binary: "uint", size: 8 },
];
const prefixItem = (prefix) => ({
    name: "prefix",
    binary: "bytes",
    custom: Uint8Array.from(prefix),
    omit: true,
});
export const nativeTokenTransferLayout = [
    prefixItem([0x99, 0x4e, 0x54, 0x54]),
    { name: "trimmedAmount", binary: "bytes", layout: trimmedAmountLayout },
    { name: "sourceToken", ...layoutItems.universalAddressItem },
    { name: "recipientAddress", ...layoutItems.universalAddressItem },
    { name: "recipientChain", ...layoutItems.chainItem() }, //TODO restrict to supported chains?
];
export const transceiverMessageLayout = (prefix, nttManagerPayload, transceiverPayload) => [
    prefixItem(prefix),
    { name: "sourceNttManager", ...layoutItems.universalAddressItem },
    { name: "recipientNttManager", ...layoutItems.universalAddressItem },
    customizableBytes({ name: "nttManagerPayload", lengthSize: 2 }, nttManagerPayload),
    customizableBytes({ name: "transceiverPayload", lengthSize: 2 }, transceiverPayload),
];
export const nttManagerMessageLayout = (customPayload) => [
    { name: "id", binary: "bytes", size: 32 },
    { name: "sender", ...layoutItems.universalAddressItem },
    customizableBytes({ name: "payload", lengthSize: 2 }, customPayload),
];
const optionalWormholeTransceiverPayloadLayout = [
    { name: "version", binary: "uint", size: 2, custom: 1, omit: true },
    {
        name: "forSpecializedRelayer",
        binary: "uint",
        size: 1,
        custom: {
            to: (val) => val > 0,
            from: (val) => (val ? 1 : 0),
        },
    },
];
const optionalWormholeTransceiverPayloadConversion = {
    to: (encoded) => encoded.length === 0
        ? null
        : deserializeLayout(optionalWormholeTransceiverPayloadLayout, encoded),
    from: (value) => value === null
        ? new Uint8Array(0)
        : serializeLayout(optionalWormholeTransceiverPayloadLayout, value),
};
export const wormholeTransceiverMessageLayout = (nttManagerPayload) => transceiverMessageLayout([0x99, 0x45, 0xff, 0x10], nttManagerPayload, optionalWormholeTransceiverPayloadConversion);
const wormholeNativeTokenTransferLayout = wormholeTransceiverMessageLayout(nttManagerMessageLayout(nativeTokenTransferLayout));
export const transceiverInstructionLayout = (customPayload) => [
    { name: "index", binary: "uint", size: 1 },
    customizableBytes({ name: "payload", lengthSize: 1 }, customPayload),
];
export const nttNamedPayloads = [
    ["WormholeTransfer", wormholeNativeTokenTransferLayout],
];
registerPayloadTypes("Ntt", nttNamedPayloads);
//# sourceMappingURL=nttLayout.js.map